==> nextcloud-app-calendar-1.5.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/zh_CN.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "日历",
    "%s has published the calendar »%s«" : "%s 已经发布了日历 »%s«",
    "Hello," : "你好，",
    "We wanted to inform you that %s has published the calendar »%s«." : "我们想通知您，%s 已发布日历»%s«。",
    "Open »%s«" : "打开 »%s«",
    "Cheers!" : "干杯！",
    "Recipient" : "容器",
    "Too many redirects. Aborting ..." : "太多重定向。取消中...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "远程服务器日程无法访问 (HTTP {%s} 错误)",
    "Error connecting to remote server" : "连接远程服务器出错",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "获取远程服务器资源出错。可能由于未通过鉴定导致。",
    "Error requesting resource on remote server" : " 获取远程服务器资源出错",
    "Individual" : "个人",
    "Group" : "群组",
    "Resource" : "源",
    "Room" : "房间",
    "Unknown" : "未知",
    "Required" : "必填",
    "Optional" : "选填",
    "Does not attend" : "不参加",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "您处于未知时区({tz}),请调整回UTC时间",
    "Please create a calendar first." : "请先创建一个新的日历。",
    "New event" : "新事件",
    "CalDAV address for clients" : "客户的 CalDAV 地址",
    "Error saving WebCal-calendar" : "保存WebCal日历时出错",
    "WebDAV address for subscriptions" : "订阅的WebDAV地址",
    "Email has been sent." : "邮件已经发送。",
    "There was an issue while sending your email." : "发送邮件过程中出现了问题。",
    "group" : "群组",
    "Details" : "细节",
    "Attendees" : "参加者",
    "Reminders" : "提醒",
    "Repeating" : "重复",
    "When shared show full event" : "共享时显示完整事件",
    "When shared show only busy" : "共享时仅显示进行中的事件",
    "When shared hide this event" : "共享时隐藏本事件",
    "Confirmed" : "已确认",
    "Tentative" : "暂定",
    "Cancelled" : "已取消",
    "Please add a title." : "请添加标题。",
    "Please select a calendar." : "请选择一个日历",
    "The event can not end before it starts." : "事件不能在开始之前结束。",
    "Global" : "全局",
    "None" : "不提醒",
    "Every day" : "每天",
    "Every week" : "每周",
    "Every month" : "每月",
    "Every year" : "每年",
    "never" : "从不",
    "after" : "之后",
    "How about getting started by importing some calendars?" : "开始导入日历好吗？",
    "At time of event" : "在事件发生的",
    "5 minutes before" : "5分钟前",
    "10 minutes before" : "10分钟前",
    "15 minutes before" : "15分钟前",
    "30 minutes before" : "30分钟前",
    "1 hour before" : "1小时前",
    "2 hours before" : "2小时前",
    "Custom" : "自定义",
    "Audio" : "声音提醒",
    "Email" : "电子邮件",
    "Pop-up" : "弹窗提醒",
    "sec" : "秒",
    "min" : "分钟",
    "hours" : "小时",
    "days" : "天",
    "week" : "周",
    "before" : "之前",
    "start" : "开始",
    "end" : "结束",
    "Editing reminders of unknown type not supported." : "不支持未知类型的编辑提醒",
    "Week {number} of {year}" : "{year}年的第{number}周",
    "{type} {time} before the event starts" : "事件开始前 {type} {time} ",
    "{type} {time} before the event ends" : "事件结束前 {type} {time} ",
    "{type} {time} after the event starts" : "事件开始后 {type} {time} ",
    "{type} {time} after the event ends" : "事件结束后 {type} {time} ",
    "{type} at the event's start" : "{type} 事件开始时",
    "{type} at the event's end" : "{type} 事件结束时",
    "{type} at {time}" : "{type} {time}",
    "{calendar} shared by {owner}" : "{calendar} 由 {owner} 共享",
    "Please enter a valid WebCal-URL" : "请输入有效的WebCal地址",
    "Severe error in webcal proxy. Please contact administrator for more information." : "webcal代理中出现严重错误。 要获取更详细信息，请与管理员联系。",
    "Title of the Event" : "事件标题",
    "Starts" : "开始于",
    "Ends" : "结束于",
    "All day Event" : "全天事件",
    "Delete" : "删除",
    "Cancel" : "取消",
    "More ..." : "更多...",
    "Create" : "创建",
    "Update" : "更新",
    "Close" : "关闭",
    "Location" : "地点",
    "Description" : "描述",
    "Event status" : "事件状态",
    "Visibility when sharing" : "共享时是否可见",
    "Export" : "导出",
    "%s has published the calendar %s" : "%s 发布了日历 %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "我们想通知您 %s 发布了日历 {boldstart}%s{boldend}.",
    "Click here to access it" : "点这里访问",
    "We wanted to inform you that %s has published the calendar %s." : "我们想要提醒您 %s 发布了日历 %s.",
    "Click on the link below to access it" : "点击链接访问",
    "Day" : "天",
    "Week" : "星期",
    "Month" : "月",
    "Today" : "今天",
    "Some events in this calendar are broken. Please check the JS console for more info." : "日历中的某些事件已损坏。更多信息请在JS控制台中查看。",
    "Share Calendar" : "共享日历",
    "Shared" : "已共享",
    "More" : "更多",
    "Edit" : "编辑",
    "Link" : "链接",
    "iCal link" : "iCal 链接",
    "Download" : "下载",
    "Share with users or groups" : "共享给其他组或者用户",
    "can edit" : "可编辑",
    "Share link" : "分享链接",
    "Public access" : "公开访问",
    "Email link to person" : "邮寄链接",
    "Send" : "发送",
    "New Calendar" : "新建日历",
    "Name" : "名称",
    "New Subscription" : "新的订阅",
    "Go back" : "回到上一步",
    "Go forward" : "向前",
    "Calendar does not exist" : "日历不存在",
    "Maybe you got a wrong link or the calendar was unshared?" : "也许你访问了错误的连接或者此日历未被分享？",
    "Edit event" : "编辑事件",
    "Delete Event" : "删除事件",
    "Save Event" : "保存事件",
    "Time" : "时间",
    "Type" : "类型",
    "Relative" : "相对",
    "Absolute" : "绝对",
    "Repeat" : "重复",
    "times every" : "次每",
    "Add" : "增加",
    "Email address of attendee" : "参加者的邮箱地址",
    "Please add your email address in the personal settings in order to add attendees." : "请在个人设置中设置您的邮箱地址以便添加为参与者",
    "from" : "从",
    "to" : "到",
    "This event's repeating rule is not supported yet." : "此事件的重复规则还没有被支持。",
    "Support for advanced rules will be added with subsequent updates." : "将在后续的更新中添加对高级规则的支持。",
    "Reset repeating rule" : "重置重复规则",
    "Repeat every ..." : "重复",
    "end repeat ..." : "结束重复",
    "times" : "次数",
    "Import Calendars" : "导入日历",
    "Import canceled" : "导入已取消",
    "Analyzing calendar" : "分析日历",
    "The file contains objects incompatible with the selected calendar" : "该文件包含的内容与选择的日历不兼容",
    "New calendar" : "新建日历",
    "File is empty" : "文件是空的",
    "Import scheduled" : "导入时间表",
    "%s shared the calendar <strong>%s</strong> with you" : "%s给你分享了日历 <strong>%s</strong>",
    "Embed" : "嵌入",
    "Iframe to integrate" : "整合iframe",
    "Publish URL" : "发布 URL",
    "Settings & import" : "设置 & 导入",
    "Skip simple event editor" : "跳过简单事件编辑器",
    "Show week numbers" : "显示周次",
    "Import calendar" : "导入日历",
    "No Calendars selected for import" : "未选择要导入的日历",
    "Primary CalDAV address" : "主要的 CalDAV 地址",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV 地址",
    "Subscribe" : "订阅"
},
"nplurals=1; plural=0;");

==> nextcloud-app-calendar-1.6.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/zh_CN.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "日历",
    "%s has published the calendar »%s«" : "%s 已经发布了日历 »%s«",
    "Hello," : "你好，",
    "We wanted to inform you that %s has published the calendar »%s«." : "我们想通知您，%s 已发布日历»%s«。",
    "Open »%s«" : "打开 »%s«",
    "Cheers!" : "干杯！",
    "Recipient" : "容器",
    "Too many redirects. Aborting ..." : "太多重定向。取消中...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "远程服务器日程无法访问 (HTTP {%s} 错误)",
    "Error connecting to remote server" : "连接远程服务器出错",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "获取远程服务器资源出错。可能由于未通过鉴定导致。",
    "Error requesting resource on remote server" : " 获取远程服务器资源出错",
    "Individual" : "个人",
    "Group" : "群组",
    "Resource" : "源",
    "Room" : "房间",
    "Unknown" : "未知",
    "Required" : "必填",
    "Optional" : "选填",
    "Does not attend" : "不参加",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "您处于未知时区({tz}),请调整回UTC时间",
    "Please create a calendar first." : "请先创建一个新的日历。",
    "New event" : "新事件",
    "CalDAV address for clients" : "客户的 CalDAV 地址",
    "Some events in this calendar are broken. Please check the JS console for more info." : "日历中的某些事件已损坏。更多信息请在JS控制台中查看。",
    "Share Calendar" : "共享日历",
    "Shared" : "已共享",
    "WebDAV address for subscriptions" : "订阅的WebDAV地址",
    "Could not send your email." : "无法发送您的电子邮件。",
    "group" : "群组",
    "Details" : "细节",
    "Attendees" : "参加者",
    "Reminders" : "提醒",
    "Repeating" : "重复",
    "When shared show full event" : "共享时显示完整事件",
    "When shared show only busy" : "共享时仅显示进行中的事件",
    "When shared hide this event" : "共享时隐藏本事件",
    "Confirmed" : "已确认",
    "Tentative" : "暂定",
    "Cancelled" : "已取消",
    "Please add a title." : "请添加标题。",
    "Please select a calendar." : "请选择一个日历",
    "The event can not end before it starts." : "事件不能在开始之前结束。",
    "Global" : "全局",
    "None" : "不提醒",
    "Every day" : "每天",
    "Every week" : "每周",
    "Every month" : "每月",
    "Every year" : "每年",
    "never" : "从不",
    "after" : "之后",
    "How about getting started by importing some calendars?" : "开始导入日历好吗？",
    "At time of event" : "在事件发生的",
    "5 minutes before" : "5分钟前",
    "10 minutes before" : "10分钟前",
    "15 minutes before" : "15分钟前",
    "30 minutes before" : "30分钟前",
    "1 hour before" : "1小时前",
    "2 hours before" : "2小时前",
    "Custom" : "自定义",
    "Audio" : "声音提醒",
    "Email" : "电子邮件",
    "Pop-up" : "弹窗提醒",
    "sec" : "秒",
    "min" : "分钟",
    "hours" : "小时",
    "days" : "天",
    "week" : "周",
    "before" : "之前",
    "start" : "开始",
    "end" : "结束",
    "Editing reminders of unknown type not supported." : "不支持未知类型的编辑提醒",
    "Week {number} of {year}" : "{year}年的第{number}周",
    "{type} {time} before the event starts" : "事件开始前 {type} {time} ",
    "{type} {time} before the event ends" : "事件结束前 {type} {time} ",
    "{type} {time} after the event starts" : "事件开始后 {type} {time} ",
    "{type} {time} after the event ends" : "事件结束后 {type} {time} ",
    "{type} at the event's start" : "{type} 事件开始时",
    "{type} at the event's end" : "{type} 事件结束时",
    "{type} at {time}" : "{type} {time}",
    "{calendar} shared by {owner}" : "{calendar} 由 {owner} 共享",
    "Please enter a valid WebCal-URL" : "请输入有效的WebCal地址",
    "Severe error in webcal proxy. Please contact administrator for more information." : "webcal代理中出现严重错误。 要获取更详细信息，请与管理员联系。",
    "Title of the Event" : "事件标题",
    "Starts" : "开始于",
    "Ends" : "结束于",
    "All day Event" : "全天事件",
    "Delete" : "删除",
    "Cancel" : "取消",
    "More ..." : "更多...",
    "Create" : "创建",
    "Update" : "更新",
    "Close" : "关闭",
    "Location" : "地点",
    "Description" : "描述",
    "Event status" : "事件状态",
    "Visibility when sharing" : "共享时是否可见",
    "Export" : "导出",
    "%s has published the calendar %s" : "%s 发布了日历 %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "我们想通知您 %s 发布了日历 {boldstart}%s{boldend}.",
    "Click here to access it" : "点这里访问",
    "We wanted to inform you that %s has published the calendar %s." : "我们想要提醒您 %s 发布了日历 %s.",
    "Click on the link below to access it" : "点击链接访问",
    "Day" : "天",
    "Week" : "星期",
    "Month" : "月",
    "Today" : "今天",
    "More" : "更多",
    "Edit" : "编辑",
    "Link" : "链接",
    "iCal link" : "iCal 链接",
    "Download" : "下载",
    "Share with users or groups" : "共享给其他组或者用户",
    "can edit" : "可编辑",
    "Share link" : "分享链接",
    "Public access" : "公开访问",
    "Email link to person" : "邮寄链接",
    "Send" : "发送",
    "New Calendar" : "新建日历",
    "Name" : "名称",
    "New Subscription" : "新的订阅",
    "Go back" : "回到上一步",
    "Go forward" : "向前",
    "Calendar does not exist" : "日历不存在",
    "Maybe you got a wrong link or the calendar was unshared?" : "也许你访问了错误的连接或者此日历未被分享？",
    "Edit event" : "编辑事件",
    "Delete Event" : "删除事件",
    "Save Event" : "保存事件",
    "Time" : "时间",
    "Type" : "类型",
    "Relative" : "相对",
    "Absolute" : "绝对",
    "Repeat" : "重复",
    "times every" : "次每",
    "Add" : "增加",
    "Email address of attendee" : "参加者的邮箱地址",
    "Please add your email address in the personal settings in order to add attendees." : "请在个人设置中设置您的邮箱地址以便添加为参与者",
    "from" : "从",
    "to" : "到",
    "This event's repeating rule is not supported yet." : "此事件的重复规则还没有被支持。",
    "Support for advanced rules will be added with subsequent updates." : "将在后续的更新中添加对高级规则的支持。",
    "Reset repeating rule" : "重置重复规则",
    "Repeat every ..." : "重复",
    "end repeat ..." : "结束重复",
    "times" : "次数",
    "Import Calendars" : "导入日历",
    "Import canceled" : "导入已取消",
    "Analyzing calendar" : "分析日历",
    "The file contains objects incompatible with the selected calendar" : "该文件包含的内容与选择的日历不兼容",
    "New calendar" : "新建日历",
    "File is empty" : "文件是空的",
    "Import scheduled" : "导入时间表",
    "%s shared the calendar <strong>%s</strong> with you" : "%s给你分享了日历 <strong>%s</strong>",
    "Embed" : "嵌入",
    "Iframe to integrate" : "整合iframe",
    "Publish URL" : "发布 URL",
    "Settings & import" : "设置 & 导入",
    "Skip simple event editor" : "跳过简单事件编辑器",
    "Show week numbers" : "显示周次",
    "Import calendar" : "导入日历",
    "No Calendars selected for import" : "未选择要导入的日历",
    "Primary CalDAV address" : "主要的 CalDAV 地址",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV 地址",
    "Subscribe" : "订阅"
},
"nplurals=1; plural=0;");
